/**
 * @license
 * Copyright 2021 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
/// <amd-module name="@tensorflow/tfjs-backend-webgpu/dist/shader_preprocessor" />
import { DataType } from '@tensorflow/tfjs-core';
export declare function getCoordsDataType(rank: number): string;
export declare function getCoordsXYZ(index: number): string;
interface ProgramParams {
    dispatchLayout: {
        x: number[];
        y?: number[];
        z?: number[];
    };
    workGroupSize: [number, number, number];
    variableNames: string[];
    uniforms?: string;
    isVec4?: boolean;
    size?: boolean;
    atomic?: boolean;
    getUserCode: () => string;
}
export interface InputInfo {
    dtype: DataType;
    shape: number[];
    name: string;
}
export declare function getWorkGroupSizeString(): string;
export declare function getMainHeaderString(): string;
export declare function getMainHeaderAndGlobalIndexString(): string;
export declare function makeShader(inputInfo: InputInfo[], outputData: {
    dtype: DataType;
    shape: number[];
}, program: ProgramParams, isFromPixel?: boolean): string;
export declare function getInputByOutputSnippet(inputInfo: InputInfo, outShape: number[], isVec4: boolean, isFlatDispatchLayout: boolean): string;
/**
 * Generates getOutputCoords() function that computes output coordinates from
 * dispatch geometry to reduce arithmetic.
 */
export declare function getOutputCoordsSnippet(outShape: number[], dispatchLayout: {
    x: number[];
    y?: number[];
    z?: number[];
}): [string, number];
export {};
