/**
 * @license
 * Copyright 2019 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
/// <amd-module name="@tensorflow/tfjs-backend-webgpu/dist/webgpu_program" />
/// <reference types="@webgpu/types/dist" />
import { DataType, Rank, ShapeMap, TensorInfo } from '@tensorflow/tfjs-core';
import * as shader_preprocessor from './shader_preprocessor';
export interface WebGPUProgram {
    shaderKey: string;
    outputShape: number[];
    dispatchLayout: {
        x: number[];
        y?: number[];
        z?: number[];
    };
    dispatch: [number, number, number];
    variableNames: string[];
    uniforms?: string;
    workPerThread?: number;
    workGroupSize: [number, number, number];
    isVec4?: boolean;
    size?: boolean;
    atomic?: boolean;
    getUserCode: () => string;
}
export interface TensorData {
    dtype: DataType;
}
export declare const makeBindGroup: (device: GPUDevice, bindGroupLayout: GPUBindGroupLayout, inputs: GPUBindingResource[], output: GPUBindingResource, uniforms?: GPUBindingResource) => GPUBindGroup;
export declare const compileProgram: (device: GPUDevice, program: WebGPUProgram, pipelineLayout: GPUPipelineLayout, inputsData: shader_preprocessor.InputInfo[], output: TensorInfo, isFromPixel?: boolean) => GPUComputePipeline;
export declare function makeShaderKey<R extends Rank>(program: WebGPUProgram, shapes: Array<ShapeMap[R]>, types?: string[], broadcastDimsKey?: string, inputShapesEqualsOutShape?: string): string;
